@@ -482,6 +482,21 @@ public:
         return str;
     }
 
+    enum StopReason {
+        UNDEFINED_REASON=0,
+        BREAKPOINT_HIT,
+        WATCHPOINT_TRIGGER,
+        READ_WATCHPOINT_TRIGGER,
+        ACCESS_WATCHPOINT_TRIGGER,
+        FUNCTION_FINISHED,
+        LOCATION_REACHED,
+        WATCHPOINT_SCOPE,
+        END_STEPPING_RANGE,
+        EXITED_SIGNALLED,
+        EXITED,
+        EXITED_NORMALLY,
+        SIGNAL_RECEIVED
+    };//end enum StopReason
 
     virtual ~IDebugger () {}
 
@@ -532,7 +547,7 @@ public:
                                         got_overloads_choice_signal () const=0;
 
     virtual sigc::signal<void,
-                         const UString&/*reason*/,
+                         IDebugger::StopReason /*reason*/,
                          bool /*has frame*/,
                          const IDebugger::Frame&/*the frame*/,
                          int /*thread id*/,
@@ -687,6 +702,8 @@ public:
 
     virtual void detach_from_target (const UString &a_cookie="") = 0;
 
+    virtual bool is_attached_to_target () const =0;
+
     virtual void add_env_variables (const map<UString, UString> &a_vars) = 0;
 
     virtual map<UString, UString>& get_env_variables () = 0;
@@ -713,6 +730,8 @@ public:
 
     virtual void step_out (const UString &a_cookie="") = 0;
 
+    virtual void step_instruction (const UString &a_cookie="") = 0;
+
     virtual void continue_to_position (const UString &a_path,
                                        gint a_line_num,
                                        const UString &a_cookie="") = 0;
