@@ -15,7 +15,7 @@
  *See the GNU General Public License for more details.
  *
  *You should have received a copy of the
- *GNU General Public License along with Goupil;
+ *GNU General Public License along with Nemiver;
  *see the file COPYING.
  *If not, write to the Free Software Foundation,
  *Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -26,8 +26,8 @@
 #define __NEMIVER_RUN_PROGRAM_DIALOG_H__
 
 #include <map>
+#include "common/nmv-safe-ptr-utils.h"
 #include "nmv-dialog.h"
-#include "nmv-safe-ptr-utils.h"
 
 NEMIVER_BEGIN_NAMESPACE (nemiver)
 
